@@ -41,7 +41,8 @@ import threading
 from urllib.parse import urlencode, parse_qs, urlsplit, urlunsplit
 import urllib3.exceptions
 
-from ..common import pf_common as pfc
+# from ..common import pf_common as pfc
+from pi3dpf_ns.pi3dpf_common import pf_common as pfc
 from .echo import Devices as devices
 from .echo import Device
 from .echo import DeviceClass
@@ -236,7 +237,7 @@ class Alexa:
         self.visualize = AlexaNowPlayingVisualize(self.config)
         self.visualize.fifo_open('write_noblock')
         self.nothing_playing = os.path.join(
-            os.path.dirname(__file__), '..', 'common', 'cfg', 'icons', '1x1-transparent.png')
+            os.path.dirname(__file__), '..', 'cfg', 'icons', '1x1-transparent.png')
         shutil.copyfile(self.nothing_playing, self.PI3D_NOW_PLAYING_BM)
         self.now_playing(init=ScheduleMode.init)
         self.song_changed = False
