@@ -24,8 +24,8 @@ import traceback
 import urllib.error
 from urllib.request import urlopen
 
-from ..common import pf_common as pfc
-
+# from ..common import pf_common as pfc
+from pi3dpf_ns.pi3dpf_common import pf_common as pfc
 _log = logging.getLogger(os.path.basename(__file__))
 
 
@@ -338,8 +338,9 @@ class AlexaNowPlayingVisualize:
     def get_skill_defs(self):
         fnames, i, must_reload = (self.alexa_skill_configs, 0, False)
         # todo: extract file names from PI3D_NOW_PLAYING_SKILL_DEFS
-        for f in [os.path.join(os.path.dirname(__file__), '..', 'common', 'cfg', 'now-playing-skills.config'),
-                  '/home/pi/.pf/alexa/now-playing-skills.config']:
+        for f in self.PI3D_NOW_PLAYING_SKILL_DEFS:
+        # for f in [os.path.join(os.path.dirname(__file__), '..', 'common', 'cfg', 'now-playing-skills.config'),
+        #           '/home/pi/.pf/alexa/now-playing-skills.config']:
             if not os.path.exists(f):
                 continue
             mdate, must_reload = (os.path.getmtime(f), False)
